@@ -3,39 +3,17 @@ package Combine::Keys;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+use base 'Import::Export';
+
+our $VERSION = '0.08';
 require XSLoader;
 XSLoader::load('Combine::Keys', $VERSION);
 
-our %EXPORTING = (
+our %EX= (
     ckeys		=> [qw/all xs/], 
     combine_keys	=> [qw/all perl/],
 );
 
-sub import {
-	my ($pkg, @export) = @_;
-	my $caller = caller();
-	export($pkg, $caller, @export);
-}
-
-sub export {
-	my ($pkg, $caller) = (shift, shift);
-	while (my $ex = shift) {
-		if (! exists $EXPORTING{$ex} ) {
-		 	my @export = grep { 
-				grep { $_ eq $ex } @{ $EXPORTING{$_} }
-			} keys %EXPORTING;
-			@export 
-				? return export($pkg, $caller, (@export, @_))
-				: die "$ex is not exported";
-		}
-		
-		no strict 'refs';
-		$caller->can($ex) and next; # qw/all perl/
-		*{"${caller}::${ex}"} = \&{"${pkg}::${ex}"};
-	}
-}
-
 sub combine_keys {
     return @{ ckeys([@_]) };
 }
@@ -46,7 +24,7 @@ Combine::Keys - keys on multiple hash references
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
